Files
linux/drivers
Ian Munsie 8ac75b96be cxl: Use call_rcu to reduce latency when releasing the afu fd
The afu fd release path was identified as a significant bottleneck in
the overall performance of cxl. While an optimal AFU design would
minimise the need to close & reopen the AFU fd, it is not always
practical to avoid.

The bottleneck seems to be down to the call to synchronize_rcu(), which
will block until every other thread is guaranteed to be out of an RCU
critical section. Replace it with call_rcu() to free the context
structures later so we can return to the application sooner.

This reduces the time spent in the fd release path from 13356 usec to
13.3 usec - about a 100x speed up.

Reported-by: Fei K Chen <uchen@cn.ibm.com>
Signed-off-by: Ian Munsie <imunsie@au1.ibm.com>
Signed-off-by: Michael Ellerman <mpe@ellerman.id.au>
2015-06-03 13:27:15 +10:00
..
…
…
…
…
…
…
…
…
…
2015-04-17 15:32:07 -04:00
…
2015-04-30 16:48:53 -04:00
…
…
…
…
…
…
2015-04-23 16:55:50 +02:00
2015-04-27 10:10:19 -07:00
…
…
…
…
…
…
…
…
…
…
…